Class: TrieveRubyClient::AuthApi
- Inherits:
-
Object
- Object
- TrieveRubyClient::AuthApi
- Defined in:
- lib/trieve_ruby_client/api/auth_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#callback(opts = {}) ⇒ SlimUser
openid_callback openid_callback This is the callback route for the OAuth provider, it should not be called directly.
-
#callback_with_http_info(opts = {}) ⇒ Array<(SlimUser, Integer, Hash)>
openid_callback openid_callback This is the callback route for the OAuth provider, it should not be called directly.
-
#get_me(opts = {}) ⇒ SlimUser
get_me get_me Get the user corresponding to your current auth credentials.
-
#get_me_with_http_info(opts = {}) ⇒ Array<(SlimUser, Integer, Hash)>
get_me get_me Get the user corresponding to your current auth credentials.
-
#initialize(api_client = ApiClient.default) ⇒ AuthApi
constructor
A new instance of AuthApi.
-
#login(opts = {}) ⇒ nil
login login This will redirect you to the OAuth provider for authentication with email/pass, SSO, Google, Github, etc.
-
#login_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
login login This will redirect you to the OAuth provider for authentication with email/pass, SSO, Google, Github, etc.
-
#logout(opts = {}) ⇒ nil
logout logout Invalidate your current auth credential stored typically stored in a cookie.
-
#logout_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
logout logout Invalidate your current auth credential stored typically stored in a cookie.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#callback(opts = {}) ⇒ SlimUser
openid_callback openid_callback This is the callback route for the OAuth provider, it should not be called directly. Redirects to browser with set-cookie header.
26 27 28 29 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 26 def callback(opts = {}) data, _status_code, _headers = callback_with_http_info(opts) data end |
#callback_with_http_info(opts = {}) ⇒ Array<(SlimUser, Integer, Hash)>
openid_callback openid_callback This is the callback route for the OAuth provider, it should not be called directly. Redirects to browser with set-cookie header.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 35 def callback_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthApi.callback ...' end # resource path local_var_path = '/api/auth/callback' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SlimUser' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AuthApi.callback", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthApi#callback\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_me(opts = {}) ⇒ SlimUser
get_me get_me Get the user corresponding to your current auth credentials.
83 84 85 86 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 83 def get_me(opts = {}) data, _status_code, _headers = get_me_with_http_info(opts) data end |
#get_me_with_http_info(opts = {}) ⇒ Array<(SlimUser, Integer, Hash)>
get_me get_me Get the user corresponding to your current auth credentials.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 92 def get_me_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthApi.get_me ...' end # resource path local_var_path = '/api/auth/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SlimUser' # auth_names auth_names = opts[:debug_auth_names] || ['Cookie', 'ApiKey'] = opts.merge( :operation => :"AuthApi.get_me", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthApi#get_me\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#login(opts = {}) ⇒ nil
login login This will redirect you to the OAuth provider for authentication with email/pass, SSO, Google, Github, etc.
143 144 145 146 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 143 def login(opts = {}) login_with_http_info(opts) nil end |
#login_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
login login This will redirect you to the OAuth provider for authentication with email/pass, SSO, Google, Github, etc.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 155 def login_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthApi.login ...' end # resource path local_var_path = '/api/auth' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['inv_code'] = opts[:'inv_code'] if !opts[:'inv_code'].nil? form_params['organization_id'] = opts[:'organization_id'] if !opts[:'organization_id'].nil? form_params['redirect_uri'] = opts[:'redirect_uri'] if !opts[:'redirect_uri'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AuthApi.login", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthApi#login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#logout(opts = {}) ⇒ nil
logout logout Invalidate your current auth credential stored typically stored in a cookie. This does not invalidate your API key.
211 212 213 214 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 211 def logout(opts = {}) logout_with_http_info(opts) nil end |
#logout_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
logout logout Invalidate your current auth credential stored typically stored in a cookie. This does not invalidate your API key.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/trieve_ruby_client/api/auth_api.rb', line 220 def logout_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthApi.logout ...' end # resource path local_var_path = '/api/auth' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AuthApi.logout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthApi#logout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |