Class: TrieveRubyClient::AutocompleteReqPayload
- Inherits:
-
Object
- Object
- TrieveRubyClient::AutocompleteReqPayload
- Defined in:
- lib/trieve_ruby_client/models/autocomplete_req_payload.rb
Instance Attribute Summary collapse
-
#content_only ⇒ Object
Set content_only to true to only returning the chunk_html of the chunks.
-
#extend_results ⇒ Object
If specified to true, this will extend the search results to include non-exact prefix matches of the same search_type such that a full page_size of results are returned.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#highlight_delimiters ⇒ Object
Set highlight_delimiters to a list of strings to use as delimiters for highlighting.
-
#highlight_max_length ⇒ Object
Set highlight_max_length to control the maximum number of tokens (typically whitespace separated strings, but sometimes also word stems) which can be present within a single highlight.
-
#highlight_max_num ⇒ Object
Set highlight_max_num to control the maximum number of highlights per chunk.
-
#highlight_results ⇒ Object
Set highlight_results to false for a slight latency improvement (1-10ms).
-
#highlight_threshold ⇒ Object
Set highlight_threshold to a lower or higher value to adjust the sensitivity of the highlights applied to the chunk html.
-
#highlight_window ⇒ Object
Set highlight_window to a number to control the amount of words that are returned around the matched phrases.
-
#page_size ⇒ Object
Page size is the number of chunks to fetch.
-
#query ⇒ Object
Query is the search query.
-
#recency_bias ⇒ Object
Recency Bias lets you determine how much of an effect the recency of chunks will have on the search results.
-
#score_threshold ⇒ Object
Set score_threshold to a float to filter out chunks with a score below the threshold.
-
#search_type ⇒ Object
Can be either "semantic", or "fulltext".
-
#slim_chunks ⇒ Object
Set slim_chunks to true to avoid returning the content and chunk_html of the chunks.
-
#tag_weights ⇒ Object
Tag weights is a JSON object which can be used to boost the ranking of chunks with certain tags.
-
#use_weights ⇒ Object
Set use_weights to true to use the weights of the chunks in the result set in order to sort them.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutocompleteReqPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AutocompleteReqPayload
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrieveRubyClient::AutocompleteReqPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrieveRubyClient::AutocompleteReqPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'content_only') self.content_only = attributes[:'content_only'] end if attributes.key?(:'extend_results') self.extend_results = attributes[:'extend_results'] end if attributes.key?(:'filters') self.filters = attributes[:'filters'] end if attributes.key?(:'highlight_delimiters') if (value = attributes[:'highlight_delimiters']).is_a?(Array) self.highlight_delimiters = value end end if attributes.key?(:'highlight_max_length') self.highlight_max_length = attributes[:'highlight_max_length'] end if attributes.key?(:'highlight_max_num') self.highlight_max_num = attributes[:'highlight_max_num'] end if attributes.key?(:'highlight_results') self.highlight_results = attributes[:'highlight_results'] end if attributes.key?(:'highlight_threshold') self.highlight_threshold = attributes[:'highlight_threshold'] end if attributes.key?(:'highlight_window') self.highlight_window = attributes[:'highlight_window'] end if attributes.key?(:'page_size') self.page_size = attributes[:'page_size'] end if attributes.key?(:'query') self.query = attributes[:'query'] else self.query = nil end if attributes.key?(:'recency_bias') self.recency_bias = attributes[:'recency_bias'] end if attributes.key?(:'score_threshold') self.score_threshold = attributes[:'score_threshold'] end if attributes.key?(:'search_type') self.search_type = attributes[:'search_type'] else self.search_type = nil end if attributes.key?(:'slim_chunks') self.slim_chunks = attributes[:'slim_chunks'] end if attributes.key?(:'tag_weights') if (value = attributes[:'tag_weights']).is_a?(Hash) self.tag_weights = value end end if attributes.key?(:'use_weights') self.use_weights = attributes[:'use_weights'] end end |
Instance Attribute Details
#content_only ⇒ Object
Set content_only to true to only returning the chunk_html of the chunks. This is useful for when you want to reduce amount of data over the wire for latency improvement (typically 10-50ms). Default is false.
19 20 21 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 19 def content_only @content_only end |
#extend_results ⇒ Object
If specified to true, this will extend the search results to include non-exact prefix matches of the same search_type such that a full page_size of results are returned. Default is false.
22 23 24 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 22 def extend_results @extend_results end |
#filters ⇒ Object
Returns the value of attribute filters.
24 25 26 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 24 def filters @filters end |
#highlight_delimiters ⇒ Object
Set highlight_delimiters to a list of strings to use as delimiters for highlighting. If not specified, this defaults to ["?", ",", ".", "!"]. These are the characters that will be used to split the chunk_html into splits for highlighting.
27 28 29 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 27 def highlight_delimiters @highlight_delimiters end |
#highlight_max_length ⇒ Object
Set highlight_max_length to control the maximum number of tokens (typically whitespace separated strings, but sometimes also word stems) which can be present within a single highlight. If not specified, this defaults to 8. This is useful to shorten large splits which may have low scores due to length compared to the query. Set to something very large like 100 to highlight entire splits.
30 31 32 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 30 def highlight_max_length @highlight_max_length end |
#highlight_max_num ⇒ Object
Set highlight_max_num to control the maximum number of highlights per chunk. If not specified, this defaults to 3. It may be less than 3 if no snippets score above the highlight_threshold.
33 34 35 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 33 def highlight_max_num @highlight_max_num end |
#highlight_results ⇒ Object
Set highlight_results to false for a slight latency improvement (1-10ms). If not specified, this defaults to true. This will add ‘<b><mark>` tags to the chunk_html of the chunks to highlight matching splits and return the highlights on each scored chunk in the response.
36 37 38 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 36 def highlight_results @highlight_results end |
#highlight_threshold ⇒ Object
Set highlight_threshold to a lower or higher value to adjust the sensitivity of the highlights applied to the chunk html. If not specified, this defaults to 0.8. The range is 0.0 to 1.0.
39 40 41 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 39 def highlight_threshold @highlight_threshold end |
#highlight_window ⇒ Object
Set highlight_window to a number to control the amount of words that are returned around the matched phrases. If not specified, this defaults to 0. This is useful for when you want to show more context around the matched words. When specified, window/2 whitespace separated words are added before and after each highlight in the response’s highlights array. If an extended highlight overlaps with another highlight, the overlapping words are only included once.
42 43 44 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 42 def highlight_window @highlight_window end |
#page_size ⇒ Object
Page size is the number of chunks to fetch. This can be used to fetch more than 10 chunks at a time.
45 46 47 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 45 def page_size @page_size end |
#query ⇒ Object
Query is the search query. This can be any string. The query will be used to create an embedding vector and/or SPLADE vector which will be used to find the result set.
48 49 50 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 48 def query @query end |
#recency_bias ⇒ Object
Recency Bias lets you determine how much of an effect the recency of chunks will have on the search results. If not specified, this defaults to 0.0. We recommend setting this to 1.0 for a gentle reranking of the results, >3.0 for a strong reranking of the results.
51 52 53 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 51 def recency_bias @recency_bias end |
#score_threshold ⇒ Object
Set score_threshold to a float to filter out chunks with a score below the threshold.
54 55 56 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 54 def score_threshold @score_threshold end |
#search_type ⇒ Object
Can be either "semantic", or "fulltext". "semantic" will pull in one page_size of the nearest cosine distant vectors. "fulltext" will pull in one page_size of full-text results based on SPLADE.
57 58 59 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 57 def search_type @search_type end |
#slim_chunks ⇒ Object
Set slim_chunks to true to avoid returning the content and chunk_html of the chunks. This is useful for when you want to reduce amount of data over the wire for latency improvement (typically 10-50ms). Default is false.
60 61 62 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 60 def slim_chunks @slim_chunks end |
#tag_weights ⇒ Object
Tag weights is a JSON object which can be used to boost the ranking of chunks with certain tags. This is useful for when you want to be able to bias towards chunks with a certain tag on the fly. The keys are the tag names and the values are the weights.
63 64 65 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 63 def tag_weights @tag_weights end |
#use_weights ⇒ Object
Set use_weights to true to use the weights of the chunks in the result set in order to sort them. If not specified, this defaults to true.
66 67 68 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 66 def use_weights @use_weights end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 380 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrieveRubyClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 92 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 69 def self.attribute_map { :'content_only' => :'content_only', :'extend_results' => :'extend_results', :'filters' => :'filters', :'highlight_delimiters' => :'highlight_delimiters', :'highlight_max_length' => :'highlight_max_length', :'highlight_max_num' => :'highlight_max_num', :'highlight_results' => :'highlight_results', :'highlight_threshold' => :'highlight_threshold', :'highlight_window' => :'highlight_window', :'page_size' => :'page_size', :'query' => :'query', :'recency_bias' => :'recency_bias', :'score_threshold' => :'score_threshold', :'search_type' => :'search_type', :'slim_chunks' => :'slim_chunks', :'tag_weights' => :'tag_weights', :'use_weights' => :'use_weights' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 356 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 120 def self.openapi_nullable Set.new([ :'content_only', :'extend_results', :'filters', :'highlight_delimiters', :'highlight_max_length', :'highlight_max_num', :'highlight_results', :'highlight_threshold', :'highlight_window', :'page_size', :'recency_bias', :'score_threshold', :'slim_chunks', :'tag_weights', :'use_weights' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 97 def self.openapi_types { :'content_only' => :'Boolean', :'extend_results' => :'Boolean', :'filters' => :'ChunkFilter', :'highlight_delimiters' => :'Array<String>', :'highlight_max_length' => :'Integer', :'highlight_max_num' => :'Integer', :'highlight_results' => :'Boolean', :'highlight_threshold' => :'Float', :'highlight_window' => :'Integer', :'page_size' => :'Integer', :'query' => :'String', :'recency_bias' => :'Float', :'score_threshold' => :'Float', :'search_type' => :'String', :'slim_chunks' => :'Boolean', :'tag_weights' => :'Hash<String, Float>', :'use_weights' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 319 def ==(o) return true if self.equal?(o) self.class == o.class && content_only == o.content_only && extend_results == o.extend_results && filters == o.filters && highlight_delimiters == o.highlight_delimiters && highlight_max_length == o.highlight_max_length && highlight_max_num == o.highlight_max_num && highlight_results == o.highlight_results && highlight_threshold == o.highlight_threshold && highlight_window == o.highlight_window && page_size == o.page_size && query == o.query && recency_bias == o.recency_bias && score_threshold == o.score_threshold && search_type == o.search_type && slim_chunks == o.slim_chunks && tag_weights == o.tag_weights && use_weights == o.use_weights end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 451 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
343 344 345 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 343 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
349 350 351 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 349 def hash [content_only, extend_results, filters, highlight_delimiters, highlight_max_length, highlight_max_num, highlight_results, highlight_threshold, highlight_window, page_size, query, recency_bias, score_threshold, search_type, slim_chunks, tag_weights, use_weights].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 234 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@highlight_max_length.nil? && @highlight_max_length < 0 invalid_properties.push('invalid value for "highlight_max_length", must be greater than or equal to 0.') end if !@highlight_max_num.nil? && @highlight_max_num < 0 invalid_properties.push('invalid value for "highlight_max_num", must be greater than or equal to 0.') end if !@highlight_window.nil? && @highlight_window < 0 invalid_properties.push('invalid value for "highlight_window", must be greater than or equal to 0.') end if !@page_size.nil? && @page_size < 0 invalid_properties.push('invalid value for "page_size", must be greater than or equal to 0.') end if @query.nil? invalid_properties.push('invalid value for "query", query cannot be nil.') end if @search_type.nil? invalid_properties.push('invalid value for "search_type", search_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
427 428 429 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 427 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
421 422 423 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 421 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/trieve_ruby_client/models/autocomplete_req_payload.rb', line 266 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@highlight_max_length.nil? && @highlight_max_length < 0 return false if !@highlight_max_num.nil? && @highlight_max_num < 0 return false if !@highlight_window.nil? && @highlight_window < 0 return false if !@page_size.nil? && @page_size < 0 return false if @query.nil? return false if @search_type.nil? true end |