Class: TrieveRubyClient::ChunkReqPayload

Inherits:
Object
  • Object
show all
Defined in:
lib/trieve_ruby_client/models/chunk_req_payload.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChunkReqPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrieveRubyClient::ChunkReqPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrieveRubyClient::ChunkReqPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'boost_phrase')
    self.boost_phrase = attributes[:'boost_phrase']
  end

  if attributes.key?(:'chunk_html')
    self.chunk_html = attributes[:'chunk_html']
  end

  if attributes.key?(:'chunk_vector')
    if (value = attributes[:'chunk_vector']).is_a?(Array)
      self.chunk_vector = value
    end
  end

  if attributes.key?(:'convert_html_to_text')
    self.convert_html_to_text = attributes[:'convert_html_to_text']
  end

  if attributes.key?(:'group_ids')
    if (value = attributes[:'group_ids']).is_a?(Array)
      self.group_ids = value
    end
  end

  if attributes.key?(:'group_tracking_ids')
    if (value = attributes[:'group_tracking_ids']).is_a?(Array)
      self.group_tracking_ids = value
    end
  end

  if attributes.key?(:'image_urls')
    if (value = attributes[:'image_urls']).is_a?(Array)
      self.image_urls = value
    end
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'num_value')
    self.num_value = attributes[:'num_value']
  end

  if attributes.key?(:'split_avg')
    self.split_avg = attributes[:'split_avg']
  end

  if attributes.key?(:'tag_set')
    if (value = attributes[:'tag_set']).is_a?(Array)
      self.tag_set = value
    end
  end

  if attributes.key?(:'time_stamp')
    self.time_stamp = attributes[:'time_stamp']
  end

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'upsert_by_tracking_id')
    self.upsert_by_tracking_id = attributes[:'upsert_by_tracking_id']
  end

  if attributes.key?(:'weight')
    self.weight = attributes[:'weight']
  end
end

Instance Attribute Details

#boost_phraseObject

Returns the value of attribute boost_phrase.



18
19
20
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 18

def boost_phrase
  @boost_phrase
end

#chunk_htmlObject

HTML content of the chunk. This can also be plaintext. The innerText of the HTML will be used to create the embedding vector. The point of using HTML is for convienience, as some users have applications where users submit HTML content.



21
22
23
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 21

def chunk_html
  @chunk_html
end

#chunk_vectorObject

Chunk_vector is a vector of floats which can be used instead of generating a new embedding. This is useful for when you are using a pre-embedded dataset. If this is not provided, the innerText of the chunk_html will be used to create the embedding.



24
25
26
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 24

def chunk_vector
  @chunk_vector
end

#convert_html_to_textObject

Convert HTML to raw text before processing to avoid adding noise to the vector embeddings. By default this is true. If you are using HTML content that you want to be included in the vector embeddings, set this to false.



27
28
29
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 27

def convert_html_to_text
  @convert_html_to_text
end

#group_idsObject

Group ids are the ids of the groups that the chunk should be placed into. This is useful for when you want to create a chunk and add it to a group or multiple groups in one request. Necessary because this route queues the chunk for ingestion and the chunk may not exist yet immediately after response.



30
31
32
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 30

def group_ids
  @group_ids
end

#group_tracking_idsObject

Group tracking_ids are the tracking_ids of the groups that the chunk should be placed into. This is useful for when you want to create a chunk and add it to a group or multiple groups in one request. Necessary because this route queues the chunk for ingestion and the chunk may not exist yet immediately after response.



33
34
35
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 33

def group_tracking_ids
  @group_tracking_ids
end

#image_urlsObject

Image urls are a list of urls to images that are associated with the chunk. This is useful for when you want to associate images with a chunk.



36
37
38
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 36

def image_urls
  @image_urls
end

Link to the chunk. This can also be any string. Frequently, this is a link to the source of the chunk. The link value will not affect the embedding creation.



39
40
41
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 39

def link
  @link
end

#locationObject

Returns the value of attribute location.



41
42
43
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 41

def location
  @location
end

#metadataObject

Metadata is a JSON object which can be used to filter chunks. This is useful for when you want to filter chunks by arbitrary metadata. Unlike with tag filtering, there is a performance hit for filtering on metadata.



44
45
46
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 44

def 
  @metadata
end

#num_valueObject

Num value is an arbitrary numerical value that can be used to filter chunks. This is useful for when you want to filter chunks by numerical value. There is no performance hit for filtering on num_value.



47
48
49
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 47

def num_value
  @num_value
end

#split_avgObject

Split avg is a boolean which tells the server to split the text in the chunk_html into smaller chunks and average their resulting vectors. This is useful for when you want to create a chunk from a large piece of text and want to split it into smaller chunks to create a more fuzzy average dense vector. The sparse vector will be generated normally with no averaging. By default this is false.



50
51
52
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 50

def split_avg
  @split_avg
end

#tag_setObject

Tag set is a list of tags. This can be used to filter chunks by tag. Unlike with metadata filtering, HNSW indices will exist for each tag such that there is not a performance hit for filtering on them.



53
54
55
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 53

def tag_set
  @tag_set
end

#time_stampObject

Time_stamp should be an ISO 8601 combined date and time without timezone. It is used for time window filtering and recency-biasing search results.



56
57
58
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 56

def time_stamp
  @time_stamp
end

#tracking_idObject

Tracking_id is a string which can be used to identify a chunk. This is useful for when you are coordinating with an external system and want to use the tracking_id to identify the chunk.



59
60
61
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 59

def tracking_id
  @tracking_id
end

#upsert_by_tracking_idObject

Upsert when a chunk with the same tracking_id exists. By default this is false, and the request will fail if a chunk with the same tracking_id exists. If this is true, the chunk will be updated if a chunk with the same tracking_id exists.



62
63
64
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 62

def upsert_by_tracking_id
  @upsert_by_tracking_id
end

#weightObject

Weight is a float which can be used to bias search results. This is useful for when you want to bias search results for a chunk. The magnitude only matters relative to other chunks in the chunk’s dataset dataset.



65
66
67
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 65

def weight
  @weight
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 313

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = TrieveRubyClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 68

def self.attribute_map
  {
    :'boost_phrase' => :'boost_phrase',
    :'chunk_html' => :'chunk_html',
    :'chunk_vector' => :'chunk_vector',
    :'convert_html_to_text' => :'convert_html_to_text',
    :'group_ids' => :'group_ids',
    :'group_tracking_ids' => :'group_tracking_ids',
    :'image_urls' => :'image_urls',
    :'link' => :'link',
    :'location' => :'location',
    :'metadata' => :'metadata',
    :'num_value' => :'num_value',
    :'split_avg' => :'split_avg',
    :'tag_set' => :'tag_set',
    :'time_stamp' => :'time_stamp',
    :'tracking_id' => :'tracking_id',
    :'upsert_by_tracking_id' => :'upsert_by_tracking_id',
    :'weight' => :'weight'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 289

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 119

def self.openapi_nullable
  Set.new([
    :'boost_phrase',
    :'chunk_html',
    :'chunk_vector',
    :'convert_html_to_text',
    :'group_ids',
    :'group_tracking_ids',
    :'image_urls',
    :'link',
    :'location',
    :'metadata',
    :'num_value',
    :'split_avg',
    :'tag_set',
    :'time_stamp',
    :'tracking_id',
    :'upsert_by_tracking_id',
    :'weight'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 96

def self.openapi_types
  {
    :'boost_phrase' => :'BoostPhrase',
    :'chunk_html' => :'String',
    :'chunk_vector' => :'Array<Float>',
    :'convert_html_to_text' => :'Boolean',
    :'group_ids' => :'Array<String>',
    :'group_tracking_ids' => :'Array<String>',
    :'image_urls' => :'Array<String>',
    :'link' => :'String',
    :'location' => :'GeoInfo',
    :'metadata' => :'Object',
    :'num_value' => :'Float',
    :'split_avg' => :'Boolean',
    :'tag_set' => :'Array<String>',
    :'time_stamp' => :'String',
    :'tracking_id' => :'String',
    :'upsert_by_tracking_id' => :'Boolean',
    :'weight' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 252

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      boost_phrase == o.boost_phrase &&
      chunk_html == o.chunk_html &&
      chunk_vector == o.chunk_vector &&
      convert_html_to_text == o.convert_html_to_text &&
      group_ids == o.group_ids &&
      group_tracking_ids == o.group_tracking_ids &&
      image_urls == o.image_urls &&
      link == o.link &&
      location == o.location &&
       == o. &&
      num_value == o.num_value &&
      split_avg == o.split_avg &&
      tag_set == o.tag_set &&
      time_stamp == o.time_stamp &&
      tracking_id == o.tracking_id &&
      upsert_by_tracking_id == o.upsert_by_tracking_id &&
      weight == o.weight
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 384

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 276

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



282
283
284
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 282

def hash
  [boost_phrase, chunk_html, chunk_vector, convert_html_to_text, group_ids, group_tracking_ids, image_urls, link, location, , num_value, split_avg, tag_set, time_stamp, tracking_id, upsert_by_tracking_id, weight].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



237
238
239
240
241
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 237

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 360

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 354

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
# File 'lib/trieve_ruby_client/models/chunk_req_payload.rb', line 245

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end