Class: TrieveRubyClient::ContentChunkMetadata
- Inherits:
-
Object
- Object
- TrieveRubyClient::ContentChunkMetadata
- Defined in:
- lib/trieve_ruby_client/models/content_chunk_metadata.rb
Instance Attribute Summary collapse
-
#chunk_html ⇒ Object
Returns the value of attribute chunk_html.
-
#id ⇒ Object
Returns the value of attribute id.
-
#image_urls ⇒ Object
Returns the value of attribute image_urls.
-
#num_value ⇒ Object
Returns the value of attribute num_value.
-
#qdrant_point_id ⇒ Object
Returns the value of attribute qdrant_point_id.
-
#time_stamp ⇒ Object
Returns the value of attribute time_stamp.
-
#tracking_id ⇒ Object
Returns the value of attribute tracking_id.
-
#weight ⇒ Object
Returns the value of attribute weight.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContentChunkMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ContentChunkMetadata
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrieveRubyClient::ContentChunkMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrieveRubyClient::ContentChunkMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chunk_html') self.chunk_html = attributes[:'chunk_html'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'image_urls') if (value = attributes[:'image_urls']).is_a?(Array) self.image_urls = value end end if attributes.key?(:'num_value') self.num_value = attributes[:'num_value'] end if attributes.key?(:'qdrant_point_id') self.qdrant_point_id = attributes[:'qdrant_point_id'] end if attributes.key?(:'time_stamp') self.time_stamp = attributes[:'time_stamp'] end if attributes.key?(:'tracking_id') self.tracking_id = attributes[:'tracking_id'] end if attributes.key?(:'weight') self.weight = attributes[:'weight'] else self.weight = nil end end |
Instance Attribute Details
#chunk_html ⇒ Object
Returns the value of attribute chunk_html.
18 19 20 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 18 def chunk_html @chunk_html end |
#id ⇒ Object
Returns the value of attribute id.
20 21 22 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 20 def id @id end |
#image_urls ⇒ Object
Returns the value of attribute image_urls.
22 23 24 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 22 def image_urls @image_urls end |
#num_value ⇒ Object
Returns the value of attribute num_value.
24 25 26 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 24 def num_value @num_value end |
#qdrant_point_id ⇒ Object
Returns the value of attribute qdrant_point_id.
26 27 28 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 26 def qdrant_point_id @qdrant_point_id end |
#time_stamp ⇒ Object
Returns the value of attribute time_stamp.
28 29 30 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 28 def time_stamp @time_stamp end |
#tracking_id ⇒ Object
Returns the value of attribute tracking_id.
30 31 32 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 30 def tracking_id @tracking_id end |
#weight ⇒ Object
Returns the value of attribute weight.
32 33 34 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 32 def weight @weight end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 212 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrieveRubyClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 49 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 35 def self.attribute_map { :'chunk_html' => :'chunk_html', :'id' => :'id', :'image_urls' => :'image_urls', :'num_value' => :'num_value', :'qdrant_point_id' => :'qdrant_point_id', :'time_stamp' => :'time_stamp', :'tracking_id' => :'tracking_id', :'weight' => :'weight' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 68 def self.openapi_nullable Set.new([ :'chunk_html', :'image_urls', :'num_value', :'qdrant_point_id', :'time_stamp', :'tracking_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 54 def self.openapi_types { :'chunk_html' => :'String', :'id' => :'String', :'image_urls' => :'Array<String>', :'num_value' => :'Float', :'qdrant_point_id' => :'String', :'time_stamp' => :'Time', :'tracking_id' => :'String', :'weight' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && chunk_html == o.chunk_html && id == o.id && image_urls == o.image_urls && num_value == o.num_value && qdrant_point_id == o.qdrant_point_id && time_stamp == o.time_stamp && tracking_id == o.tracking_id && weight == o.weight end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 283 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 181 def hash [chunk_html, id, image_urls, num_value, qdrant_point_id, time_stamp, tracking_id, weight].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @weight.nil? invalid_properties.push('invalid value for "weight", weight cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
259 260 261 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 259 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 253 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 |
# File 'lib/trieve_ruby_client/models/content_chunk_metadata.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @weight.nil? true end |