Class: TrieveRubyClient::DatasetApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trieve_ruby_client/api/dataset_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DatasetApi

Returns a new instance of DatasetApi.



19
20
21
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#clear_dataset(tr_dataset, dataset_id, opts = {}) ⇒ nil

Clear Dataset Clear Dataset Clears a dataset. The auth’ed user must be an owner of the organization to clear a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to clear.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


28
29
30
31
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 28

def clear_dataset(tr_dataset, dataset_id, opts = {})
  clear_dataset_with_http_info(tr_dataset, dataset_id, opts)
  nil
end

#clear_dataset_with_http_info(tr_dataset, dataset_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Clear Dataset Clear Dataset Clears a dataset. The auth&#39;ed user must be an owner of the organization to clear a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to clear.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 39

def clear_dataset_with_http_info(tr_dataset, dataset_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.clear_dataset ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.clear_dataset"
  end
  # verify the required parameter 'dataset_id' is set
  if @api_client.config.client_side_validation && dataset_id.nil?
    fail ArgumentError, "Missing the required parameter 'dataset_id' when calling DatasetApi.clear_dataset"
  end
  # resource path
  local_var_path = '/api/dataset/clear/{dataset_id}'.sub('{' + 'dataset_id' + '}', CGI.escape(dataset_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.clear_dataset",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#clear_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_dataset(tr_organization, create_dataset_request, opts = {}) ⇒ Dataset

Create dataset Create dataset Create a new dataset. The auth’ed user must be an owner of the organization to create a dataset.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • create_dataset_request (CreateDatasetRequest)

    JSON request payload to create a new dataset

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 98

def create_dataset(tr_organization, create_dataset_request, opts = {})
  data, _status_code, _headers = create_dataset_with_http_info(tr_organization, create_dataset_request, opts)
  data
end

#create_dataset_with_http_info(tr_organization, create_dataset_request, opts = {}) ⇒ Array<(Dataset, Integer, Hash)>

Create dataset Create dataset Create a new dataset. The auth&#39;ed user must be an owner of the organization to create a dataset.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • create_dataset_request (CreateDatasetRequest)

    JSON request payload to create a new dataset

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Dataset, Integer, Hash)>)

    Dataset data, response status code and response headers



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 109

def create_dataset_with_http_info(tr_organization, create_dataset_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.create_dataset ...'
  end
  # verify the required parameter 'tr_organization' is set
  if @api_client.config.client_side_validation && tr_organization.nil?
    fail ArgumentError, "Missing the required parameter 'tr_organization' when calling DatasetApi.create_dataset"
  end
  # verify the required parameter 'create_dataset_request' is set
  if @api_client.config.client_side_validation && create_dataset_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_dataset_request' when calling DatasetApi.create_dataset"
  end
  # resource path
  local_var_path = '/api/dataset'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'TR-Organization'] = tr_organization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_dataset_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Dataset'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.create_dataset",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#create_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_dataset(tr_dataset, dataset_id, opts = {}) ⇒ nil

Delete Dataset Delete Dataset Delete a dataset. The auth’ed user must be an owner of the organization to delete a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to delete.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


173
174
175
176
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 173

def delete_dataset(tr_dataset, dataset_id, opts = {})
  delete_dataset_with_http_info(tr_dataset, dataset_id, opts)
  nil
end

#delete_dataset_by_tracking_id(tr_dataset, tracking_id, opts = {}) ⇒ nil

Delete Dataset by Tracking ID Delete Dataset by Tracking ID Delete a dataset by its tracking id. The auth’ed user must be an owner of the organization to delete a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • tracking_id (String)

    The tracking id of the dataset you want to delete.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


243
244
245
246
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 243

def delete_dataset_by_tracking_id(tr_dataset, tracking_id, opts = {})
  delete_dataset_by_tracking_id_with_http_info(tr_dataset, tracking_id, opts)
  nil
end

#delete_dataset_by_tracking_id_with_http_info(tr_dataset, tracking_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Dataset by Tracking ID Delete Dataset by Tracking ID Delete a dataset by its tracking id. The auth&#39;ed user must be an owner of the organization to delete a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • tracking_id (String)

    The tracking id of the dataset you want to delete.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 254

def delete_dataset_by_tracking_id_with_http_info(tr_dataset, tracking_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.delete_dataset_by_tracking_id ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.delete_dataset_by_tracking_id"
  end
  # verify the required parameter 'tracking_id' is set
  if @api_client.config.client_side_validation && tracking_id.nil?
    fail ArgumentError, "Missing the required parameter 'tracking_id' when calling DatasetApi.delete_dataset_by_tracking_id"
  end
  # resource path
  local_var_path = '/api/dataset/tracking_id/{tracking_id}'.sub('{' + 'tracking_id' + '}', CGI.escape(tracking_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.delete_dataset_by_tracking_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#delete_dataset_by_tracking_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_dataset_with_http_info(tr_dataset, dataset_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Dataset Delete Dataset Delete a dataset. The auth&#39;ed user must be an owner of the organization to delete a dataset.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to delete.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 184

def delete_dataset_with_http_info(tr_dataset, dataset_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.delete_dataset ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.delete_dataset"
  end
  # verify the required parameter 'dataset_id' is set
  if @api_client.config.client_side_validation && dataset_id.nil?
    fail ArgumentError, "Missing the required parameter 'dataset_id' when calling DatasetApi.delete_dataset"
  end
  # resource path
  local_var_path = '/api/dataset/{dataset_id}'.sub('{' + 'dataset_id' + '}', CGI.escape(dataset_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.delete_dataset",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#delete_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_client_dataset_config(tr_dataset, opts = {}) ⇒ ClientDatasetConfiguration

Get Client Configuration Get Client Configuration Get the client configuration for a dataset. Will use the TR-D

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



312
313
314
315
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 312

def get_client_dataset_config(tr_dataset, opts = {})
  data, _status_code, _headers = get_client_dataset_config_with_http_info(tr_dataset, opts)
  data
end

#get_client_dataset_config_with_http_info(tr_dataset, opts = {}) ⇒ Array<(ClientDatasetConfiguration, Integer, Hash)>

Get Client Configuration Get Client Configuration Get the client configuration for a dataset. Will use the TR-D

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ClientDatasetConfiguration, Integer, Hash)>)

    ClientDatasetConfiguration data, response status code and response headers



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 322

def get_client_dataset_config_with_http_info(tr_dataset, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.get_client_dataset_config ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.get_client_dataset_config"
  end
  # resource path
  local_var_path = '/api/dataset/envs'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ClientDatasetConfiguration'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.get_client_dataset_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#get_client_dataset_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_dataset(tr_dataset, dataset_id, opts = {}) ⇒ Dataset

Get Dataset Get Dataset Get a dataset by id. Auth’ed user or api key must have an admin or owner role for the specified dataset’s organization.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



377
378
379
380
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 377

def get_dataset(tr_dataset, dataset_id, opts = {})
  data, _status_code, _headers = get_dataset_with_http_info(tr_dataset, dataset_id, opts)
  data
end

#get_dataset_with_http_info(tr_dataset, dataset_id, opts = {}) ⇒ Array<(Dataset, Integer, Hash)>

Get Dataset Get Dataset Get a dataset by id. Auth&#39;ed user or api key must have an admin or owner role for the specified dataset&#39;s organization.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Dataset, Integer, Hash)>)

    Dataset data, response status code and response headers



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 388

def get_dataset_with_http_info(tr_dataset, dataset_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.get_dataset ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.get_dataset"
  end
  # verify the required parameter 'dataset_id' is set
  if @api_client.config.client_side_validation && dataset_id.nil?
    fail ArgumentError, "Missing the required parameter 'dataset_id' when calling DatasetApi.get_dataset"
  end
  # resource path
  local_var_path = '/api/dataset/{dataset_id}'.sub('{' + 'dataset_id' + '}', CGI.escape(dataset_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Dataset'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.get_dataset",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#get_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_datasets_from_organization(tr_organization, organization_id, opts = {}) ⇒ Array<DatasetAndUsage>

Get Datasets from Organization Get Datasets from Organization Get all datasets for an organization. Auth’ed user or api key must have an admin or owner role for the specified dataset’s organization.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • organization_id (String)

    id of the organization you want to retrieve datasets for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of records to return

  • :offset (Integer)

    The number of records to skip

Returns:



449
450
451
452
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 449

def get_datasets_from_organization(tr_organization, organization_id, opts = {})
  data, _status_code, _headers = get_datasets_from_organization_with_http_info(tr_organization, organization_id, opts)
  data
end

#get_datasets_from_organization_with_http_info(tr_organization, organization_id, opts = {}) ⇒ Array<(Array<DatasetAndUsage>, Integer, Hash)>

Get Datasets from Organization Get Datasets from Organization Get all datasets for an organization. Auth&#39;ed user or api key must have an admin or owner role for the specified dataset&#39;s organization.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • organization_id (String)

    id of the organization you want to retrieve datasets for

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of records to return

  • :offset (Integer)

    The number of records to skip

Returns:

  • (Array<(Array<DatasetAndUsage>, Integer, Hash)>)

    Array<DatasetAndUsage> data, response status code and response headers



462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 462

def get_datasets_from_organization_with_http_info(tr_organization, organization_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.get_datasets_from_organization ...'
  end
  # verify the required parameter 'tr_organization' is set
  if @api_client.config.client_side_validation && tr_organization.nil?
    fail ArgumentError, "Missing the required parameter 'tr_organization' when calling DatasetApi.get_datasets_from_organization"
  end
  # verify the required parameter 'organization_id' is set
  if @api_client.config.client_side_validation && organization_id.nil?
    fail ArgumentError, "Missing the required parameter 'organization_id' when calling DatasetApi.get_datasets_from_organization"
  end
  # resource path
  local_var_path = '/api/dataset/organization/{organization_id}'.sub('{' + 'organization_id' + '}', CGI.escape(organization_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Organization'] = tr_organization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<DatasetAndUsage>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.get_datasets_from_organization",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#get_datasets_from_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_usage_by_dataset_id(tr_dataset, dataset_id, opts = {}) ⇒ DatasetUsageCount

Get Usage By Dataset ID Get Usage By Dataset ID Get the usage for a dataset by its id.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to retrieve usage for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



523
524
525
526
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 523

def get_usage_by_dataset_id(tr_dataset, dataset_id, opts = {})
  data, _status_code, _headers = get_usage_by_dataset_id_with_http_info(tr_dataset, dataset_id, opts)
  data
end

#get_usage_by_dataset_id_with_http_info(tr_dataset, dataset_id, opts = {}) ⇒ Array<(DatasetUsageCount, Integer, Hash)>

Get Usage By Dataset ID Get Usage By Dataset ID Get the usage for a dataset by its id.

Parameters:

  • tr_dataset (String)

    The dataset id to use for the request

  • dataset_id (String)

    The id of the dataset you want to retrieve usage for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DatasetUsageCount, Integer, Hash)>)

    DatasetUsageCount data, response status code and response headers



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 534

def get_usage_by_dataset_id_with_http_info(tr_dataset, dataset_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.get_usage_by_dataset_id ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling DatasetApi.get_usage_by_dataset_id"
  end
  # verify the required parameter 'dataset_id' is set
  if @api_client.config.client_side_validation && dataset_id.nil?
    fail ArgumentError, "Missing the required parameter 'dataset_id' when calling DatasetApi.get_usage_by_dataset_id"
  end
  # resource path
  local_var_path = '/api/dataset/usage/{dataset_id}'.sub('{' + 'dataset_id' + '}', CGI.escape(dataset_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DatasetUsageCount'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.get_usage_by_dataset_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#get_usage_by_dataset_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_dataset(tr_organization, update_dataset_request, opts = {}) ⇒ Dataset

Update Dataset Update Dataset Update a dataset. The auth’ed user must be an owner of the organization to update a dataset.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • update_dataset_request (UpdateDatasetRequest)

    JSON request payload to update a dataset

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



593
594
595
596
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 593

def update_dataset(tr_organization, update_dataset_request, opts = {})
  data, _status_code, _headers = update_dataset_with_http_info(tr_organization, update_dataset_request, opts)
  data
end

#update_dataset_with_http_info(tr_organization, update_dataset_request, opts = {}) ⇒ Array<(Dataset, Integer, Hash)>

Update Dataset Update Dataset Update a dataset. The auth&#39;ed user must be an owner of the organization to update a dataset.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • update_dataset_request (UpdateDatasetRequest)

    JSON request payload to update a dataset

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Dataset, Integer, Hash)>)

    Dataset data, response status code and response headers



604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/trieve_ruby_client/api/dataset_api.rb', line 604

def update_dataset_with_http_info(tr_organization, update_dataset_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DatasetApi.update_dataset ...'
  end
  # verify the required parameter 'tr_organization' is set
  if @api_client.config.client_side_validation && tr_organization.nil?
    fail ArgumentError, "Missing the required parameter 'tr_organization' when calling DatasetApi.update_dataset"
  end
  # verify the required parameter 'update_dataset_request' is set
  if @api_client.config.client_side_validation && update_dataset_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_dataset_request' when calling DatasetApi.update_dataset"
  end
  # resource path
  local_var_path = '/api/dataset'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'TR-Organization'] = tr_organization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_dataset_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Dataset'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"DatasetApi.update_dataset",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DatasetApi#update_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end