Class: TrieveRubyClient::EventsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trieve_ruby_client/api/events_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EventsApi



19
20
21
# File 'lib/trieve_ruby_client/api/events_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trieve_ruby_client/api/events_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_events(tr_dataset, get_events_data, opts = {}) ⇒ EventReturn

Get events for the dataset Get events for the dataset specified by the TR-Dataset header.



28
29
30
31
# File 'lib/trieve_ruby_client/api/events_api.rb', line 28

def get_events(tr_dataset, get_events_data, opts = {})
  data, _status_code, _headers = get_events_with_http_info(tr_dataset, get_events_data, opts)
  data
end

#get_events_with_http_info(tr_dataset, get_events_data, opts = {}) ⇒ Array<(EventReturn, Integer, Hash)>

Get events for the dataset Get events for the dataset specified by the TR-Dataset header.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/trieve_ruby_client/api/events_api.rb', line 39

def get_events_with_http_info(tr_dataset, get_events_data, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EventsApi.get_events ...'
  end
  # verify the required parameter 'tr_dataset' is set
  if @api_client.config.client_side_validation && tr_dataset.nil?
    fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling EventsApi.get_events"
  end
  # verify the required parameter 'get_events_data' is set
  if @api_client.config.client_side_validation && get_events_data.nil?
    fail ArgumentError, "Missing the required parameter 'get_events_data' when calling EventsApi.get_events"
  end
  # resource path
  local_var_path = '/api/events'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'TR-Dataset'] = tr_dataset

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(get_events_data)

  # return_type
  return_type = opts[:debug_return_type] || 'EventReturn'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"EventsApi.get_events",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EventsApi#get_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end