Class: TrieveRubyClient::MetricsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trieve_ruby_client/api/metrics_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MetricsApi



19
20
21
# File 'lib/trieve_ruby_client/api/metrics_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trieve_ruby_client/api/metrics_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_metrics(opts = {}) ⇒ String

Get Prometheus Metrics This route allows you to view the number of items in each queue in the Prometheus format.



26
27
28
29
# File 'lib/trieve_ruby_client/api/metrics_api.rb', line 26

def get_metrics(opts = {})
  data, _status_code, _headers = get_metrics_with_http_info(opts)
  data
end

#get_metrics_with_http_info(opts = {}) ⇒ Array<(String, Integer, Hash)>

Get Prometheus Metrics This route allows you to view the number of items in each queue in the Prometheus format.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/trieve_ruby_client/api/metrics_api.rb', line 35

def get_metrics_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MetricsApi.get_metrics ...'
  end
  # resource path
  local_var_path = '/metrics'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'String'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['X-API-KEY']

  new_options = opts.merge(
    :operation => :"MetricsApi.get_metrics",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MetricsApi#get_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end