Class: TrieveRubyClient::StripeApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trieve_ruby_client/api/stripe_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ StripeApi

Returns a new instance of StripeApi.



19
20
21
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel_subscription(tr_organization, subscription_id, opts = {}) ⇒ nil

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • subscription_id (String)

    id of the subscription you want to cancel

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


26
27
28
29
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 26

def cancel_subscription(tr_organization, subscription_id, opts = {})
  cancel_subscription_with_http_info(tr_organization, subscription_id, opts)
  nil
end

#cancel_subscription_with_http_info(tr_organization, subscription_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Returns nil, response status code and response headers.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • subscription_id (String)

    id of the subscription you want to cancel

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 35

def cancel_subscription_with_http_info(tr_organization, subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StripeApi.cancel_subscription ...'
  end
  # verify the required parameter 'tr_organization' is set
  if @api_client.config.client_side_validation && tr_organization.nil?
    fail ArgumentError, "Missing the required parameter 'tr_organization' when calling StripeApi.cancel_subscription"
  end
  # verify the required parameter 'subscription_id' is set
  if @api_client.config.client_side_validation && subscription_id.nil?
    fail ArgumentError, "Missing the required parameter 'subscription_id' when calling StripeApi.cancel_subscription"
  end
  # resource path
  local_var_path = '/api/stripe/subscription/{subscription_id}'.sub('{' + 'subscription_id' + '}', CGI.escape(subscription_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Organization'] = tr_organization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Cookie', 'ApiKey']

  new_options = opts.merge(
    :operation => :"StripeApi.cancel_subscription",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StripeApi#cancel_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Parameters:

  • plan_id (String)

    id of the plan you want to subscribe to

  • organization_id (String)

    id of the organization you want to subscribe to the plan

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


92
93
94
95
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 92

def direct_to_payment_link(plan_id, organization_id, opts = {})
  direct_to_payment_link_with_http_info(plan_id, organization_id, opts)
  nil
end

Returns nil, response status code and response headers.

Parameters:

  • plan_id (String)

    id of the plan you want to subscribe to

  • organization_id (String)

    id of the organization you want to subscribe to the plan

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 101

def direct_to_payment_link_with_http_info(plan_id, organization_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StripeApi.direct_to_payment_link ...'
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling StripeApi.direct_to_payment_link"
  end
  # verify the required parameter 'organization_id' is set
  if @api_client.config.client_side_validation && organization_id.nil?
    fail ArgumentError, "Missing the required parameter 'organization_id' when calling StripeApi.direct_to_payment_link"
  end
  # resource path
  local_var_path = '/api/stripe/payment_link/{plan_id}/{organization_id}'.sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s)).sub('{' + 'organization_id' + '}', CGI.escape(organization_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"StripeApi.direct_to_payment_link",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StripeApi#direct_to_payment_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_plans(opts = {}) ⇒ Array<StripePlan>

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



155
156
157
158
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 155

def get_all_plans(opts = {})
  data, _status_code, _headers = get_all_plans_with_http_info(opts)
  data
end

#get_all_plans_with_http_info(opts = {}) ⇒ Array<(Array<StripePlan>, Integer, Hash)>

Returns Array<StripePlan> data, response status code and response headers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<StripePlan>, Integer, Hash)>)

    Array<StripePlan> data, response status code and response headers



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 162

def get_all_plans_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StripeApi.get_all_plans ...'
  end
  # resource path
  local_var_path = '/api/stripe/plans'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<StripePlan>'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"StripeApi.get_all_plans",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StripeApi#get_all_plans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_subscription_plan(tr_organization, subscription_id, plan_id, opts = {}) ⇒ nil

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • subscription_id (String)

    id of the subscription you want to update

  • plan_id (String)

    id of the plan you want to subscribe to

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


211
212
213
214
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 211

def update_subscription_plan(tr_organization, subscription_id, plan_id, opts = {})
  update_subscription_plan_with_http_info(tr_organization, subscription_id, plan_id, opts)
  nil
end

#update_subscription_plan_with_http_info(tr_organization, subscription_id, plan_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Returns nil, response status code and response headers.

Parameters:

  • tr_organization (String)

    The organization id to use for the request

  • subscription_id (String)

    id of the subscription you want to update

  • plan_id (String)

    id of the plan you want to subscribe to

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/trieve_ruby_client/api/stripe_api.rb', line 221

def update_subscription_plan_with_http_info(tr_organization, subscription_id, plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: StripeApi.update_subscription_plan ...'
  end
  # verify the required parameter 'tr_organization' is set
  if @api_client.config.client_side_validation && tr_organization.nil?
    fail ArgumentError, "Missing the required parameter 'tr_organization' when calling StripeApi.update_subscription_plan"
  end
  # verify the required parameter 'subscription_id' is set
  if @api_client.config.client_side_validation && subscription_id.nil?
    fail ArgumentError, "Missing the required parameter 'subscription_id' when calling StripeApi.update_subscription_plan"
  end
  # verify the required parameter 'plan_id' is set
  if @api_client.config.client_side_validation && plan_id.nil?
    fail ArgumentError, "Missing the required parameter 'plan_id' when calling StripeApi.update_subscription_plan"
  end
  # resource path
  local_var_path = '/api/stripe/subscription_plan/{subscription_id}/{plan_id}'.sub('{' + 'subscription_id' + '}', CGI.escape(subscription_id.to_s)).sub('{' + 'plan_id' + '}', CGI.escape(plan_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'TR-Organization'] = tr_organization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Cookie', 'ApiKey']

  new_options = opts.merge(
    :operation => :"StripeApi.update_subscription_plan",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: StripeApi#update_subscription_plan\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end