Method: TrieveRubyClient::UpdateChunkData#tag_set

Defined in:
lib/trieve_ruby_client/models/update_chunk_data.rb

#tag_setObject

Tag set is a list of tags. This can be used to filter chunks by tag. Unlike with metadata filtering, HNSW indices will exist for each tag such that there is not a performance hit for filtering on them. If no tag_set is provided, the existing tag_set will be used.



42
43
44
# File 'lib/trieve_ruby_client/models/update_chunk_data.rb', line 42

def tag_set
  @tag_set
end