Class: TrieveRubyClient::CreateMessageReqPayload
- Inherits:
-
Object
- Object
- TrieveRubyClient::CreateMessageReqPayload
- Defined in:
- lib/trieve_ruby_client/models/create_message_req_payload.rb
Instance Attribute Summary collapse
-
#completion_first ⇒ Object
Completion first decides whether the stream should contain the stream of the completion response or the chunks first.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#frequency_penalty ⇒ Object
Frequency penalty is a number between -2.0 and 2.0.
-
#highlight_delimiters ⇒ Object
The delimiters to use for highlighting the citations.
-
#highlight_results ⇒ Object
Set highlight_results to false for a slight latency improvement (1-10ms).
-
#max_tokens ⇒ Object
The maximum number of tokens to generate in the chat completion.
-
#new_message_content ⇒ Object
The content of the user message to attach to the topic and then generate an assistant message in response to.
-
#presence_penalty ⇒ Object
Presence penalty is a number between -2.0 and 2.0.
-
#search_type ⇒ Object
Search_type can be either "semantic", "fulltext", or "hybrid".
-
#stop_tokens ⇒ Object
Stop tokens are up to 4 sequences where the API will stop generating further tokens.
-
#stream_response ⇒ Object
Whether or not to stream the response.
-
#temperature ⇒ Object
What sampling temperature to use, between 0 and 2.
-
#topic_id ⇒ Object
The ID of the topic to attach the message to.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMessageReqPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateMessageReqPayload
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrieveRubyClient::CreateMessageReqPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrieveRubyClient::CreateMessageReqPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'completion_first') self.completion_first = attributes[:'completion_first'] end if attributes.key?(:'filters') self.filters = attributes[:'filters'] end if attributes.key?(:'frequency_penalty') self.frequency_penalty = attributes[:'frequency_penalty'] end if attributes.key?(:'highlight_delimiters') if (value = attributes[:'highlight_delimiters']).is_a?(Array) self.highlight_delimiters = value end end if attributes.key?(:'highlight_results') self.highlight_results = attributes[:'highlight_results'] end if attributes.key?(:'max_tokens') self.max_tokens = attributes[:'max_tokens'] end if attributes.key?(:'new_message_content') self. = attributes[:'new_message_content'] else self. = nil end if attributes.key?(:'presence_penalty') self.presence_penalty = attributes[:'presence_penalty'] end if attributes.key?(:'search_type') self.search_type = attributes[:'search_type'] end if attributes.key?(:'stop_tokens') if (value = attributes[:'stop_tokens']).is_a?(Array) self.stop_tokens = value end end if attributes.key?(:'stream_response') self.stream_response = attributes[:'stream_response'] end if attributes.key?(:'temperature') self.temperature = attributes[:'temperature'] end if attributes.key?(:'topic_id') self.topic_id = attributes[:'topic_id'] else self.topic_id = nil end end |
Instance Attribute Details
#completion_first ⇒ Object
Completion first decides whether the stream should contain the stream of the completion response or the chunks first. Default is false. Keep in mind that || is used to separate the chunks from the completion response. If || is in the completion then you may want to split on ||{ instead.
19 20 21 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 19 def completion_first @completion_first end |
#filters ⇒ Object
Returns the value of attribute filters.
21 22 23 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 21 def filters @filters end |
#frequency_penalty ⇒ Object
Frequency penalty is a number between -2.0 and 2.0. Positive values penalize new tokens based on their existing frequency in the text so far, decreasing the model’s likelihood to repeat the same line verbatim. Default is 0.7.
24 25 26 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 24 def frequency_penalty @frequency_penalty end |
#highlight_delimiters ⇒ Object
The delimiters to use for highlighting the citations. If this is not included, the default delimiters will be used. Default is ‘[".", "!", "?", "\n", "\t", ","]`.
27 28 29 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 27 def highlight_delimiters @highlight_delimiters end |
#highlight_results ⇒ Object
Set highlight_results to false for a slight latency improvement (1-10ms). If not specified, this defaults to true. This will add ‘<b><mark>` tags to the chunk_html of the chunks to highlight matching splits and return the highlights on each scored chunk in the response.
30 31 32 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 30 def highlight_results @highlight_results end |
#max_tokens ⇒ Object
The maximum number of tokens to generate in the chat completion. Default is None.
33 34 35 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 33 def max_tokens @max_tokens end |
#new_message_content ⇒ Object
The content of the user message to attach to the topic and then generate an assistant message in response to.
36 37 38 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 36 def @new_message_content end |
#presence_penalty ⇒ Object
Presence penalty is a number between -2.0 and 2.0. Positive values penalize new tokens based on whether they appear in the text so far, increasing the model’s likelihood to talk about new topics. Default is 0.7.
39 40 41 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 39 def presence_penalty @presence_penalty end |
#search_type ⇒ Object
Search_type can be either "semantic", "fulltext", or "hybrid". "hybrid" will pull in one page (10 chunks) of both semantic and full-text results then re-rank them using BAAI/bge-reranker-large. "semantic" will pull in one page (10 chunks) of the nearest cosine distant vectors. "fulltext" will pull in one page (10 chunks) of full-text results based on SPLADE. Default is "hybrid".
42 43 44 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 42 def search_type @search_type end |
#stop_tokens ⇒ Object
Stop tokens are up to 4 sequences where the API will stop generating further tokens. Default is None.
45 46 47 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 45 def stop_tokens @stop_tokens end |
#stream_response ⇒ Object
Whether or not to stream the response. If this is set to true or not included, the response will be a stream. If this is set to false, the response will be a normal JSON response. Default is true.
48 49 50 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 48 def stream_response @stream_response end |
#temperature ⇒ Object
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. Default is 0.5.
51 52 53 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 51 def temperature @temperature end |
#topic_id ⇒ Object
The ID of the topic to attach the message to.
54 55 56 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 54 def topic_id @topic_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 291 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrieveRubyClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 57 def self.attribute_map { :'completion_first' => :'completion_first', :'filters' => :'filters', :'frequency_penalty' => :'frequency_penalty', :'highlight_delimiters' => :'highlight_delimiters', :'highlight_results' => :'highlight_results', :'max_tokens' => :'max_tokens', :'new_message_content' => :'new_message_content', :'presence_penalty' => :'presence_penalty', :'search_type' => :'search_type', :'stop_tokens' => :'stop_tokens', :'stream_response' => :'stream_response', :'temperature' => :'temperature', :'topic_id' => :'topic_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 100 def self.openapi_nullable Set.new([ :'completion_first', :'filters', :'frequency_penalty', :'highlight_delimiters', :'highlight_results', :'max_tokens', :'presence_penalty', :'search_type', :'stop_tokens', :'stream_response', :'temperature', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 81 def self.openapi_types { :'completion_first' => :'Boolean', :'filters' => :'ChunkFilter', :'frequency_penalty' => :'Float', :'highlight_delimiters' => :'Array<String>', :'highlight_results' => :'Boolean', :'max_tokens' => :'Integer', :'new_message_content' => :'String', :'presence_penalty' => :'Float', :'search_type' => :'String', :'stop_tokens' => :'Array<String>', :'stream_response' => :'Boolean', :'temperature' => :'Float', :'topic_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && completion_first == o.completion_first && filters == o.filters && frequency_penalty == o.frequency_penalty && highlight_delimiters == o.highlight_delimiters && highlight_results == o.highlight_results && max_tokens == o.max_tokens && == o. && presence_penalty == o.presence_penalty && search_type == o.search_type && stop_tokens == o.stop_tokens && stream_response == o.stream_response && temperature == o.temperature && topic_id == o.topic_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 260 def hash [completion_first, filters, frequency_penalty, highlight_delimiters, highlight_results, max_tokens, , presence_penalty, search_type, stop_tokens, stream_response, temperature, topic_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 194 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@max_tokens.nil? && @max_tokens < 0 invalid_properties.push('invalid value for "max_tokens", must be greater than or equal to 0.') end if @new_message_content.nil? invalid_properties.push('invalid value for "new_message_content", new_message_content cannot be nil.') end if @topic_id.nil? invalid_properties.push('invalid value for "topic_id", topic_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 |
# File 'lib/trieve_ruby_client/models/create_message_req_payload.rb', line 214 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@max_tokens.nil? && @max_tokens < 0 return false if @new_message_content.nil? return false if @topic_id.nil? true end |