Class: TrieveRubyClient::EventsApi
- Inherits:
-
Object
- Object
- TrieveRubyClient::EventsApi
- Defined in:
- lib/trieve_ruby_client/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_events(tr_dataset, page, opts = {}) ⇒ EventReturn
get_events get_events Get events for the auth’ed user.
-
#get_events_with_http_info(tr_dataset, page, opts = {}) ⇒ Array<(EventReturn, Integer, Hash)>
get_events get_events Get events for the auth'ed user.
-
#initialize(api_client = ApiClient.default) ⇒ EventsApi
constructor
A new instance of EventsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EventsApi
Returns a new instance of EventsApi.
19 20 21 |
# File 'lib/trieve_ruby_client/api/events_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/trieve_ruby_client/api/events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_events(tr_dataset, page, opts = {}) ⇒ EventReturn
get_events get_events Get events for the auth’ed user. Currently, this is only for events belonging to the auth’ed user. Soon, we plan to associate events to datasets instead of users. Each page contains 10 events.
28 29 30 31 |
# File 'lib/trieve_ruby_client/api/events_api.rb', line 28 def get_events(tr_dataset, page, opts = {}) data, _status_code, _headers = get_events_with_http_info(tr_dataset, page, opts) data end |
#get_events_with_http_info(tr_dataset, page, opts = {}) ⇒ Array<(EventReturn, Integer, Hash)>
get_events get_events Get events for the auth'ed user. Currently, this is only for events belonging to the auth'ed user. Soon, we plan to associate events to datasets instead of users. Each page contains 10 events.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/trieve_ruby_client/api/events_api.rb', line 39 def get_events_with_http_info(tr_dataset, page, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.get_events ...' end # verify the required parameter 'tr_dataset' is set if @api_client.config.client_side_validation && tr_dataset.nil? fail ArgumentError, "Missing the required parameter 'tr_dataset' when calling EventsApi.get_events" end # verify the required parameter 'page' is set if @api_client.config.client_side_validation && page.nil? fail ArgumentError, "Missing the required parameter 'page' when calling EventsApi.get_events" end # resource path local_var_path = '/api/events/{page}'.sub('{' + 'page' + '}', CGI.escape(page.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'TR-Dataset'] = tr_dataset # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventReturn' # auth_names auth_names = opts[:debug_auth_names] || ['Cookie', 'ApiKey'] = opts.merge( :operation => :"EventsApi.get_events", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#get_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |