Method: TrieveRubyClient::SearchOverGroupsData#group_size
- Defined in:
- lib/trieve_ruby_client/models/search_over_groups_data.rb
#group_size ⇒ Object
Group_size is the number of chunks to fetch for each group. The default is 3. If a group has less than group_size chunks, all chunks will be returned. If this is set to a large number, we recommend setting slim_chunks to true to avoid returning the content and chunk_html of the chunks so as to lower the amount of time required for content download and serialization.
24 25 26 |
# File 'lib/trieve_ruby_client/models/search_over_groups_data.rb', line 24 def group_size @group_size end |